==> qt-creator-opensource-src-4.0.1.zip: qt-creator-opensource-src-4.0.1/src/libs/modelinglib/qmt/config/stringtextsource.h <==
/****************************************************************************
**
** Copyright (C) 2016 Jochen Becher
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef QMT_STRINGTEXTSOURCE_H
#define QMT_STRINGTEXTSOURCE_H

#include "textsource.h"

#include <QString>

namespace qmt {

class QMT_EXPORT StringTextSource : public ITextSource
{
public:
    StringTextSource();
    ~StringTextSource();

    void setText(const QString &text);
    int sourceId() const { return m_sourceId; }
    void setSourceId(int sourceId);

    // ITextSource interface
    SourceChar readNextChar() override;

private:
    QString m_text;
    int m_sourceId;
    int m_index;
    int m_lineNumber;
    int m_columnNumber;
};

} // namespace qmt

#endif // QMT_STRINGTEXTSOURCE_H

==> qt-creator-opensource-src-4.13.2.zip: qt-creator-opensource-src-4.13.2/src/libs/modelinglib/qmt/config/stringtextsource.h <==
/****************************************************************************
**
** Copyright (C) 2016 Jochen Becher
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "textsource.h"

#include <QString>

namespace qmt {

class QMT_EXPORT StringTextSource : public ITextSource
{
public:
    StringTextSource();
    ~StringTextSource();

    void setText(const QString &text);
    int sourceId() const { return m_sourceId; }
    void setSourceId(int sourceId);

    // ITextSource interface
    SourceChar readNextChar() override;

private:
    QString m_text;
    int m_sourceId = -1;
    int m_index = -1;
    int m_lineNumber = -1;
    int m_columnNumber = -1;
};

} // namespace qmt
